@@ -8,61 +8,70 @@
 
 import functools
 import itertools
+from warnings import warn
 
 import numpy as np
 import scipy.spatial.distance
 import pandas as pd
 
 import skbio
-from skbio.diversity.alpha._faith_pd import _faith_pd, _setup_faith_pd
+from skbio.diversity.alpha._pd import _faith_pd, _phydiv, _setup_pd
 from skbio.diversity.beta._unifrac import (
-    _setup_multiple_unweighted_unifrac, _setup_multiple_weighted_unifrac,
-    _normalize_weighted_unifrac_by_default)
-from skbio.util._decorator import experimental, deprecated
+    _setup_multiple_unweighted_unifrac,
+    _setup_multiple_weighted_unifrac,
+    _normalize_weighted_unifrac_by_default,
+)
 from skbio.stats.distance import DistanceMatrix
-from skbio.diversity._util import (_validate_counts_matrix,
-                                   _get_phylogenetic_kwargs,
-                                   _quantitative_to_qualitative_counts)
+from skbio.diversity._util import (
+    _validate_counts_matrix,
+    _get_phylogenetic_kwargs,
+    _quantitative_to_qualitative_counts,
+    _table_to_numpy,
+    _validate_table,
+)
+from skbio.util._warning import _warn_deprecated
 
 
 def _get_alpha_diversity_metric_map():
     return {
-        'ace': skbio.diversity.alpha.ace,
-        'chao1': skbio.diversity.alpha.chao1,
-        'chao1_ci': skbio.diversity.alpha.chao1_ci,
-        'berger_parker_d': skbio.diversity.alpha.berger_parker_d,
-        'brillouin_d': skbio.diversity.alpha.brillouin_d,
-        'dominance': skbio.diversity.alpha.dominance,
-        'doubles': skbio.diversity.alpha.doubles,
-        'enspie': skbio.diversity.alpha.enspie,
-        'esty_ci': skbio.diversity.alpha.esty_ci,
-        'faith_pd': skbio.diversity.alpha.faith_pd,
-        'fisher_alpha': skbio.diversity.alpha.fisher_alpha,
-        'goods_coverage': skbio.diversity.alpha.goods_coverage,
-        'heip_e': skbio.diversity.alpha.heip_e,
-        'kempton_taylor_q': skbio.diversity.alpha.kempton_taylor_q,
-        'margalef': skbio.diversity.alpha.margalef,
-        'mcintosh_d': skbio.diversity.alpha.mcintosh_d,
-        'mcintosh_e': skbio.diversity.alpha.mcintosh_e,
-        'menhinick': skbio.diversity.alpha.menhinick,
-        'michaelis_menten_fit': skbio.diversity.alpha.michaelis_menten_fit,
-        'observed_otus': skbio.diversity.alpha.observed_otus,
-        'osd': skbio.diversity.alpha.osd,
-        'pielou_e': skbio.diversity.alpha.pielou_e,
-        'robbins': skbio.diversity.alpha.robbins,
-        'shannon': skbio.diversity.alpha.shannon,
-        'simpson': skbio.diversity.alpha.simpson,
-        'simpson_e': skbio.diversity.alpha.simpson_e,
-        'singles': skbio.diversity.alpha.singles,
-        'strong': skbio.diversity.alpha.strong,
-        'gini_index': skbio.diversity.alpha.gini_index,
-        'lladser_pe': skbio.diversity.alpha.lladser_pe,
-        'lladser_ci': skbio.diversity.alpha.lladser_ci}
+        "ace": skbio.diversity.alpha.ace,
+        "chao1": skbio.diversity.alpha.chao1,
+        "chao1_ci": skbio.diversity.alpha.chao1_ci,
+        "berger_parker_d": skbio.diversity.alpha.berger_parker_d,
+        "brillouin_d": skbio.diversity.alpha.brillouin_d,
+        "dominance": skbio.diversity.alpha.dominance,
+        "doubles": skbio.diversity.alpha.doubles,
+        "enspie": skbio.diversity.alpha.enspie,
+        "esty_ci": skbio.diversity.alpha.esty_ci,
+        "faith_pd": skbio.diversity.alpha.faith_pd,
+        "fisher_alpha": skbio.diversity.alpha.fisher_alpha,
+        "goods_coverage": skbio.diversity.alpha.goods_coverage,
+        "heip_e": skbio.diversity.alpha.heip_e,
+        "kempton_taylor_q": skbio.diversity.alpha.kempton_taylor_q,
+        "margalef": skbio.diversity.alpha.margalef,
+        "mcintosh_d": skbio.diversity.alpha.mcintosh_d,
+        "mcintosh_e": skbio.diversity.alpha.mcintosh_e,
+        "menhinick": skbio.diversity.alpha.menhinick,
+        "michaelis_menten_fit": skbio.diversity.alpha.michaelis_menten_fit,
+        "observed_features": skbio.diversity.alpha.observed_features,
+        "observed_otus": skbio.diversity.alpha.observed_otus,
+        "osd": skbio.diversity.alpha.osd,
+        "pielou_e": skbio.diversity.alpha.pielou_e,
+        "robbins": skbio.diversity.alpha.robbins,
+        "shannon": skbio.diversity.alpha.shannon,
+        "simpson": skbio.diversity.alpha.simpson,
+        "simpson_e": skbio.diversity.alpha.simpson_e,
+        "singles": skbio.diversity.alpha.singles,
+        "sobs": skbio.diversity.alpha.sobs,
+        "strong": skbio.diversity.alpha.strong,
+        "gini_index": skbio.diversity.alpha.gini_index,
+        "lladser_pe": skbio.diversity.alpha.lladser_pe,
+        "lladser_ci": skbio.diversity.alpha.lladser_ci,
+    }
 
 
-@experimental(as_of="0.4.1")
 def get_alpha_diversity_metrics():
-    """ List scikit-bio's alpha diversity metrics
+    """List scikit-bio's alpha diversity metrics.
 
     The alpha diversity metrics listed here can be passed as metrics to
     ``skbio.diversity.alpha_diversity``.
@@ -83,9 +92,8 @@ def get_alpha_diversity_metrics():
     return sorted(metrics.keys())
 
 
-@experimental(as_of="0.4.1")
 def get_beta_diversity_metrics():
-    """ List scikit-bio's beta diversity metrics
+    """List scikit-bio's beta diversity metrics.
 
     The beta diversity metrics listed here can be passed as metrics to
     ``skbio.diversity.beta_diversity``.
@@ -109,12 +117,11 @@ def get_beta_diversity_metrics():
     ``scipy.spatial.distance.pdist`` for more details.
 
     """
-    return sorted(['unweighted_unifrac', 'weighted_unifrac'])
+    return sorted(["unweighted_unifrac", "weighted_unifrac"])
 
 
-@experimental(as_of="0.4.1")
 def alpha_diversity(metric, counts, ids=None, validate=True, **kwargs):
-    """ Compute alpha diversity for one or more samples
+    """Compute alpha diversity for one or more samples.
 
     Parameters
     ----------
@@ -122,14 +129,14 @@ def alpha_diversity(metric, counts, ids=None, validate=True, **kwargs):
         The alpha diversity metric to apply to the sample(s). Passing metric as
         a string is preferable as this often results in an optimized version of
         the metric being used.
-    counts : 1D or 2D array_like of ints or floats
+    counts : 1D or 2D array_like of ints or floats, Table
         Vector or matrix containing count/abundance data. If a matrix, each row
-        should contain counts of OTUs in a given sample.
+        should contain counts of taxa in a given sample.
     ids : iterable of strs, optional
         Identifiers for each sample in ``counts``. By default, samples will be
         assigned integer identifiers in the order that they were provided.
     validate: bool, optional
-        If `False`, validation of the input won't be performed. This step can
+        If ``False``, validation of the input won't be performed. This step can
         be slow, so if validation is run elsewhere it can be disabled here.
         However, invalid input data can lead to invalid results or error
         messages that are hard to interpret, so this step should not be
@@ -160,37 +167,48 @@ def alpha_diversity(metric, counts, ids=None, validate=True, **kwargs):
     skbio.diversity.beta_diversity
 
     """
+    if isinstance(counts, skbio.Table):
+        counts, ids = _validate_table(counts, ids, kwargs)
+
     metric_map = _get_alpha_diversity_metric_map()
 
     if validate:
         counts = _validate_counts_matrix(counts, ids=ids)
 
-    if metric == 'faith_pd':
-        otu_ids, tree, kwargs = _get_phylogenetic_kwargs(counts, **kwargs)
-        counts_by_node, branch_lengths = _setup_faith_pd(
-            counts, otu_ids, tree, validate, single_sample=False)
+    if metric == "faith_pd":
+        taxa, tree, kwargs = _get_phylogenetic_kwargs(counts, **kwargs)
+        counts_by_node, branch_lengths = _setup_pd(
+            counts, taxa, tree, validate, rooted=True, single_sample=False
+        )
         counts = counts_by_node
-        metric = functools.partial(_faith_pd, branch_lengths=branch_lengths)
+        metric = functools.partial(_faith_pd, branch_lengths=branch_lengths, **kwargs)
+
+    elif metric == "phydiv":
+        taxa, tree, kwargs = _get_phylogenetic_kwargs(counts, **kwargs)
+        counts_by_node, branch_lengths = _setup_pd(
+            counts, taxa, tree, validate, rooted=False, single_sample=False
+        )
+        counts = counts_by_node
+        if "rooted" not in kwargs:
+            kwargs["rooted"] = len(tree.root().children) == 2
+        if "weight" not in kwargs:
+            kwargs["weight"] = False
+        metric = functools.partial(_phydiv, branch_lengths=branch_lengths, **kwargs)
+
     elif callable(metric):
         metric = functools.partial(metric, **kwargs)
     elif metric in metric_map:
         metric = functools.partial(metric_map[metric], **kwargs)
     else:
-        raise ValueError('Unknown metric provided: %r.' % metric)
+        raise ValueError("Unknown metric provided: %r." % metric)
 
     # kwargs is provided here so an error is raised on extra kwargs
     results = [metric(c, **kwargs) for c in counts]
     return pd.Series(results, index=ids)
 
 
-@deprecated(as_of='0.5.0', until='0.6.0',
-            reason=('The return type is unstable. Developer caution is '
-                    'advised. The resulting DistanceMatrix object will '
-                    'include zeros when distance has not been calculated, and '
-                    'therefore can be misleading.'))
-def partial_beta_diversity(metric, counts, ids, id_pairs, validate=True,
-                           **kwargs):
-    """Compute distances only between specified ID pairs
+def partial_beta_diversity(metric, counts, ids, id_pairs, validate=True, **kwargs):
+    """Compute distances only between specified ID pairs.
 
     Parameters
     ----------
@@ -200,7 +218,7 @@ def partial_beta_diversity(metric, counts, ids, id_pairs, validate=True,
         callable.
     counts : 2D array_like of ints or floats
         Matrix containing count/abundance data where each row contains counts
-        of OTUs in a given sample.
+        of taxa in a given sample.
     ids : iterable of strs
         Identifiers for each sample in ``counts``.
     id_pairs : iterable of tuple
@@ -219,6 +237,13 @@ def partial_beta_diversity(metric, counts, ids, id_pairs, validate=True,
         distances not defined by id_pairs will be 0.0. Use this resulting
         DistanceMatrix with caution as 0.0 is a valid distance.
 
+    Warnings
+    --------
+    ``partial_beta_diversity`` is deprecated as of ``0.5.0``. The return type is
+    unstable. Developer caution is advised. The resulting DistanceMatrix object will
+    include zeros when distance has not been calculated, and therefore can be
+    misleading.
+
     Raises
     ------
     ValueError
@@ -234,6 +259,15 @@ def partial_beta_diversity(metric, counts, ids, id_pairs, validate=True,
     skbio.diversity.get_beta_diversity_metrics
 
     """
+    # @deprecated
+    _warn_deprecated(
+        partial_beta_diversity,
+        "0.5.0",
+        msg="The return type is unstable. Developer caution is advised. The resulting "
+        "DistanceMatrix object will include zeros when distance has not been "
+        "calculated, and therefore can be misleading.",
+    )
+
     if validate:
         counts = _validate_counts_matrix(counts, ids=ids)
 
@@ -246,21 +280,21 @@ def partial_beta_diversity(metric, counts, ids, id_pairs, validate=True,
     if len(hashes) != len(id_pairs) * 2:
         raise ValueError("A duplicate or a self-self pair was observed.")
 
-    if metric == 'unweighted_unifrac':
+    if metric == "unweighted_unifrac":
         counts = _quantitative_to_qualitative_counts(counts)
-        otu_ids, tree, kwargs = _get_phylogenetic_kwargs(counts, **kwargs)
+        taxa, tree, kwargs = _get_phylogenetic_kwargs(counts, **kwargs)
         metric, counts_by_node = _setup_multiple_unweighted_unifrac(
-            counts, otu_ids=otu_ids, tree=tree, validate=validate)
+            counts, taxa=taxa, tree=tree, validate=validate
+        )
         counts = counts_by_node
-    elif metric == 'weighted_unifrac':
+    elif metric == "weighted_unifrac":
         # get the value for normalized. if it was not provided, it will fall
         # back to the default value inside of _weighted_unifrac_pdist_f
-        normalized = kwargs.pop('normalized',
-                                _normalize_weighted_unifrac_by_default)
-        otu_ids, tree, kwargs = _get_phylogenetic_kwargs(counts, **kwargs)
+        normalized = kwargs.pop("normalized", _normalize_weighted_unifrac_by_default)
+        taxa, tree, kwargs = _get_phylogenetic_kwargs(counts, **kwargs)
         metric, counts_by_node = _setup_multiple_weighted_unifrac(
-            counts, otu_ids=otu_ids, tree=tree, normalized=normalized,
-            validate=validate)
+            counts, taxa=taxa, tree=tree, normalized=normalized, validate=validate
+        )
         counts = counts_by_node
     elif callable(metric):
         metric = functools.partial(metric, **kwargs)
@@ -268,8 +302,10 @@ def partial_beta_diversity(metric, counts, ids, id_pairs, validate=True,
         # through the partial
         kwargs = {}
     else:
-        raise ValueError("partial_beta_diversity is only compatible with "
-                         "optimized unifrac methods and callable functions.")
+        raise ValueError(
+            "partial_beta_diversity is only compatible with "
+            "optimized unifrac methods and callable functions."
+        )
 
     dm = np.zeros((len(ids), len(ids)), dtype=float)
     id_index = {id_: idx for idx, id_ in enumerate(ids)}
@@ -296,7 +332,6 @@ _valid_beta_metrics = [
     "dice",
     "hamming",
     "jaccard",
-    "kulsinski",
     "mahalanobis",
     "manhattan",  # aliases to "cityblock" in beta_diversity
     "matching",
@@ -314,20 +349,19 @@ _valid_beta_metrics = [
 _qualitative_beta_metrics = [
     "dice",
     "jaccard",
-    "kulsinski",
     "matching",
     "rogerstanimoto",
     "russellrao",
     "sokalmichener",
     "sokalsneath",
-    "yule"
+    "yule",
 ]
 
 
-@experimental(as_of="0.4.0")
-def beta_diversity(metric, counts, ids=None, validate=True, pairwise_func=None,
-                   **kwargs):
-    """Compute distances between all pairs of samples
+def beta_diversity(
+    metric, counts, ids=None, validate=True, pairwise_func=None, **kwargs
+):
+    """Compute distances between all pairs of samples.
 
     Parameters
     ----------
@@ -336,15 +370,15 @@ def beta_diversity(metric, counts, ids=None, validate=True, pairwise_func=None,
         and the scikit-bio functions linked under *See Also* for available
         metrics. Passing metrics as a strings is preferable as this often
         results in an optimized version of the metric being used.
-    counts : 2D array_like of ints or floats or 2D pandas DataFrame
+    counts : 2D array_like of ints or floats, 2D pandas DataFrame, Table
         Matrix containing count/abundance data where each row contains counts
-        of OTUs in a given sample.
+        of taxa in a given sample.
     ids : iterable of strs, optional
         Identifiers for each sample in ``counts``. By default, samples will be
         assigned integer identifiers in the order that they were provided
         (where the type of the identifiers will be ``str``).
     validate : bool, optional
-        If `False`, validation of the input won't be performed. This step can
+        If ``False``, validation of the input won't be performed. This step can
         be slow, so if validation is run elsewhere it can be disabled here.
         However, invalid input data can lead to invalid results or error
         messages that are hard to interpret, so this step should not be
@@ -371,7 +405,7 @@ def beta_diversity(metric, counts, ids=None, validate=True, pairwise_func=None,
     ------
     ValueError, MissingNodeError, DuplicateNodeError
         If validation fails. Exact error will depend on what was invalid.
-    TypeError
+    iTypeError
         If invalid method-specific parameters are provided.
 
     See Also
@@ -384,6 +418,12 @@ def beta_diversity(metric, counts, ids=None, validate=True, pairwise_func=None,
     sklearn.metrics.pairwise_distances
 
     """
+    if isinstance(counts, skbio.Table):
+        counts, ids = _validate_table(counts, ids, kwargs)
+
+    if isinstance(counts, pd.DataFrame) and ids is None:
+        ids = list(counts.index)
+
     if validate:
         counts = _validate_counts_matrix(counts, ids=ids)
 
@@ -394,21 +434,21 @@ def beta_diversity(metric, counts, ids=None, validate=True, pairwise_func=None,
         # latter raises an exception over empty data.
         return DistanceMatrix(np.zeros((len(ids), len(ids))), ids)
 
-    if metric == 'unweighted_unifrac':
+    if metric == "unweighted_unifrac":
         counts = _quantitative_to_qualitative_counts(counts)
-        otu_ids, tree, kwargs = _get_phylogenetic_kwargs(counts, **kwargs)
+        taxa, tree, kwargs = _get_phylogenetic_kwargs(counts, **kwargs)
         metric, counts_by_node = _setup_multiple_unweighted_unifrac(
-            counts, otu_ids=otu_ids, tree=tree, validate=validate)
+            counts, taxa=taxa, tree=tree, validate=validate
+        )
         counts = counts_by_node
-    elif metric == 'weighted_unifrac':
+    elif metric == "weighted_unifrac":
         # get the value for normalized. if it was not provided, it will fall
         # back to the default value inside of _weighted_unifrac_pdist_f
-        normalized = kwargs.pop('normalized',
-                                _normalize_weighted_unifrac_by_default)
-        otu_ids, tree, kwargs = _get_phylogenetic_kwargs(counts, **kwargs)
+        normalized = kwargs.pop("normalized", _normalize_weighted_unifrac_by_default)
+        taxa, tree, kwargs = _get_phylogenetic_kwargs(counts, **kwargs)
         metric, counts_by_node = _setup_multiple_weighted_unifrac(
-            counts, otu_ids=otu_ids, tree=tree, normalized=normalized,
-            validate=validate)
+            counts, taxa=taxa, tree=tree, normalized=normalized, validate=validate
+        )
         counts = counts_by_node
     elif metric == "manhattan":
         metric = "cityblock"
@@ -426,7 +466,8 @@ def beta_diversity(metric, counts, ids=None, validate=True, pairwise_func=None,
             "beta_diversity as we know whether each of these should be "
             "treated as a qualitative or quantitative metric. Other metrics "
             "can be provided as functions.\n Available metrics are: %s"
-            % (metric, ', '.join(_valid_beta_metrics)))
+            % (metric, ", ".join(_valid_beta_metrics))
+        )
     else:
         # metric is a string that scikit-bio doesn't know about, for
         # example one of the SciPy metrics
