@@ -16,8 +16,9 @@ from scipy.spatial.distance import squareform
 from skbio._base import SkbioObject
 from skbio.stats._misc import _pprint_strs
 from skbio.util import find_duplicates
-from skbio.util._decorator import experimental, classonlymethod
+from skbio.util._decorator import classonlymethod
 from skbio.util._misc import resolve_key
+from skbio.util._plotting import PlottableMixin
 
 from ._utils import is_symmetric_and_hollow
 from ._utils import distmat_reorder, distmat_reorder_condensed
@@ -25,11 +26,13 @@ from ._utils import distmat_reorder, distmat_reorder_condensed
 
 class DissimilarityMatrixError(Exception):
     """General error for dissimilarity matrix validation failures."""
+
     pass
 
 
 class DistanceMatrixError(DissimilarityMatrixError):
     """General error for distance matrix validation failures."""
+
     pass
 
 
@@ -38,11 +41,10 @@ class MissingIDError(DissimilarityMatrixError):
 
     def __init__(self, missing_id):
         super(MissingIDError, self).__init__()
-        self.args = ("The ID '%s' is not in the dissimilarity matrix." %
-                     missing_id,)
+        self.args = ("The ID '%s' is not in the dissimilarity matrix." % missing_id,)
 
 
-class DissimilarityMatrix(SkbioObject):
+class DissimilarityMatrix(SkbioObject, PlottableMixin):
     """Store dissimilarities between objects.
 
     A `DissimilarityMatrix` instance stores a square, hollow, two-dimensional
@@ -91,11 +93,11 @@ class DissimilarityMatrix(SkbioObject):
     .. [1] http://docs.scipy.org/doc/scipy/reference/spatial.distance.html
 
     """
-    default_write_format = 'lsmat'
-    # Used in __str__
-    _matrix_element_name = 'dissimilarity'
 
-    @experimental(as_of="0.4.0")
+    default_write_format = "lsmat"
+    # Used in __str__
+    _matrix_element_name = "dissimilarity"
+
     def __init__(self, data, ids=None, validate=True):
         validate_full = validate
         validate_shape = False
@@ -133,14 +135,14 @@ class DissimilarityMatrix(SkbioObject):
                 _issue_copy = False
 
         if _issue_copy:
-            data = np.asarray(data, dtype='float')
+            data = np.asarray(data, dtype="float")
 
         if data.ndim == 1:
             # We can assume squareform will return a symmetric square matrix
             # so no need for full validation.
             # Still do basic checks (e.g. zero length)
             # and id validation
-            data = squareform(data, force='tomatrix', checks=False)
+            data = squareform(data, force="tomatrix", checks=False)
             validate_full = False
             validate_shape = True
             validate_ids = True
@@ -164,7 +166,6 @@ class DissimilarityMatrix(SkbioObject):
         self._id_index = self._index_list(self._ids)
 
     @classonlymethod
-    @experimental(as_of="0.5.1")
     def from_iterable(cls, iterable, metric, key=None, keys=None):
         """Create DissimilarityMatrix from an iterable given a metric.
 
@@ -198,8 +199,7 @@ class DissimilarityMatrix(SkbioObject):
         """
         iterable = list(iterable)
         if key is not None and keys is not None:
-            raise ValueError("Cannot use both `key` and `keys` at the same"
-                             " time.")
+            raise ValueError("Cannot use both `key` and `keys` at the same" " time.")
 
         keys_ = None
         if key is not None:
@@ -215,7 +215,6 @@ class DissimilarityMatrix(SkbioObject):
         return cls(dm, keys_)
 
     @property
-    @experimental(as_of="0.4.0")
     def data(self):
         """Array of dissimilarities.
 
@@ -230,7 +229,6 @@ class DissimilarityMatrix(SkbioObject):
         return self._data
 
     @property
-    @experimental(as_of="0.4.0")
     def ids(self):
         """Tuple of object IDs.
 
@@ -252,13 +250,11 @@ class DissimilarityMatrix(SkbioObject):
         self._id_index = self._index_list(self._ids)
 
     @property
-    @experimental(as_of="0.4.0")
     def dtype(self):
         """Data type of the dissimilarities."""
         return self.data.dtype
 
     @property
-    @experimental(as_of="0.4.0")
     def shape(self):
         """Two-element tuple containing the dissimilarity matrix dimensions.
 
@@ -271,7 +267,6 @@ class DissimilarityMatrix(SkbioObject):
         return self.data.shape
 
     @property
-    @experimental(as_of="0.4.0")
     def size(self):
         """Total number of elements in the dissimilarity matrix.
 
@@ -283,7 +278,6 @@ class DissimilarityMatrix(SkbioObject):
         return self.data.size
 
     @property
-    @experimental(as_of="0.4.0")
     def T(self):
         """Transpose of the dissimilarity matrix.
 
@@ -294,7 +288,6 @@ class DissimilarityMatrix(SkbioObject):
         """
         return self.transpose()
 
-    @experimental(as_of="0.4.0")
     def transpose(self):
         """Return the transpose of the dissimilarity matrix.
 
@@ -310,11 +303,8 @@ class DissimilarityMatrix(SkbioObject):
 
         """
         # Note: Skip validation, since we assume self was already validated
-        return self.__class__(self.data.T.copy(),
-                              deepcopy(self.ids),
-                              validate=False)
+        return self.__class__(self.data.T.copy(), deepcopy(self.ids), validate=False)
 
-    @experimental(as_of="0.4.0")
     def index(self, lookup_id):
         """Return the index of the specified ID.
 
@@ -339,7 +329,6 @@ class DissimilarityMatrix(SkbioObject):
         else:
             raise MissingIDError(lookup_id)
 
-    @experimental(as_of="0.4.0")
     def redundant_form(self):
         """Return an array of dissimilarities in redundant format.
 
@@ -365,7 +354,6 @@ class DissimilarityMatrix(SkbioObject):
         """
         return self.data
 
-    @experimental(as_of="0.4.0")
     def copy(self):
         """Return a deep copy of the dissimilarity matrix.
 
@@ -379,11 +367,8 @@ class DissimilarityMatrix(SkbioObject):
         # We deepcopy IDs in case the tuple contains mutable objects at some
         # point in the future.
         # Note: Skip validation, since we assume self was already validated
-        return self.__class__(self.data.copy(),
-                              deepcopy(self.ids),
-                              validate=False)
+        return self.__class__(self.data.copy(), deepcopy(self.ids), validate=False)
 
-    @experimental(as_of="0.4.0")
     def filter(self, ids, strict=True):
         """Filter the dissimilarity matrix by IDs.
 
@@ -407,6 +392,7 @@ class DissimilarityMatrix(SkbioObject):
         ------
         MissingIDError
             If an ID in `ids` is not in the object's list of IDs.
+
         """
         if tuple(self._ids) == tuple(ids):
             return self.__class__(self._data, self._ids)
@@ -433,7 +419,7 @@ class DissimilarityMatrix(SkbioObject):
         return self.__class__(filtered_data, ids, validate=False)
 
     def _stable_order(self, ids):
-        """Obtain a stable ID order with respect to self
+        """Obtain a stable ID order with respect to self.
 
         Parameters
         ----------
@@ -444,13 +430,13 @@ class DissimilarityMatrix(SkbioObject):
         -------
         np.array, dtype=int
             The corresponding index values
+
         """
         id_order = sorted(self._id_index[i] for i in ids)
         return np.array(id_order, dtype=int)
 
-    @experimental(as_of="0.5.5")
     def within(self, ids):
-        """Obtain all the distances among the set of IDs
+        """Obtain all the distances among the set of IDs.
 
         Parameters
         ----------
@@ -477,8 +463,8 @@ class DissimilarityMatrix(SkbioObject):
         ['a', 'b'] is equivalent to ['b', 'a']. The order is with respect
         to the order of the .ids attribute of self.
 
-        Example
-        -------
+        Examples
+        --------
         >>> from skbio.stats.distance import DissimilarityMatrix
         >>> dm = DissimilarityMatrix([[0, 1, 2, 3, 4], [1, 0, 1, 2, 3],
         ...                           [2, 1, 0, 1, 2], [3, 2, 1, 0, 1],
@@ -495,18 +481,19 @@ class DissimilarityMatrix(SkbioObject):
         6  C  A    2.0
         7  C  B    1.0
         8  C  C    0.0
+
         """
         ids = set(ids)
         not_present = ids - set(self._id_index)
         if not_present:
-            raise MissingIDError("At least one ID (e.g., '%s') was not "
-                                 "found." % not_present.pop())
+            raise MissingIDError(
+                "At least one ID (e.g., '%s') was not " "found." % not_present.pop()
+            )
 
         return self._subset_to_dataframe(ids, ids)
 
-    @experimental(as_of="0.5.5")
     def between(self, from_, to_, allow_overlap=False):
-        """Obtain the distances between the two groups of IDs
+        """Obtain the distances between the two groups of IDs.
 
         Parameters
         ----------
@@ -538,8 +525,8 @@ class DissimilarityMatrix(SkbioObject):
         ['a', 'b'] is equivalent to ['b', 'a']. The order is with respect to
         the .ids attribute of self.
 
-        Example
-        -------
+        Examples
+        --------
         >>> from skbio.stats.distance import DissimilarityMatrix
         >>> dm = DissimilarityMatrix([[0, 1, 2, 3, 4], [1, 0, 1, 2, 3],
         ...                           [2, 1, 0, 1, 2], [3, 2, 1, 0, 1],
@@ -553,6 +540,7 @@ class DissimilarityMatrix(SkbioObject):
         3  B  C    1.0
         4  B  D    2.0
         5  B  E    3.0
+
         """
         from_ = set(from_)
         to_ = set(to_)
@@ -560,25 +548,28 @@ class DissimilarityMatrix(SkbioObject):
         all_ids = from_ | to_
         not_present = all_ids - set(self._id_index)
         if not_present:
-            raise MissingIDError("At least one ID (e.g., '%s') was not "
-                                 "found." % not_present.pop())
+            raise MissingIDError(
+                "At least one ID (e.g., '%s') was not " "found." % not_present.pop()
+            )
 
         overlapping = from_ & to_
         if not allow_overlap and overlapping:
-            raise KeyError("At least one ID overlaps in from_ and to_ "
-                           "(e.g., '%s'). This constraint can removed with "
-                           "allow_overlap=True." % overlapping.pop())
+            raise KeyError(
+                "At least one ID overlaps in from_ and to_ "
+                "(e.g., '%s'). This constraint can removed with "
+                "allow_overlap=True." % overlapping.pop()
+            )
 
         return self._subset_to_dataframe(from_, to_)
 
     def _subset_to_dataframe(self, i_ids, j_ids):
-        """Extract a subset of self and express as a DataFrame
+        """Extract a subset of self and express as a DataFrame.
 
         Parameters
         ----------
-        i_order : Iterable of str
+        i_ids : Iterable of str
             The "from" IDs.
-        j_order : Iterable of str
+        j_ids : Iterable of str
             The "to" IDs.
 
         Notes
@@ -591,6 +582,7 @@ class DissimilarityMatrix(SkbioObject):
         pd.DataFrame
             (i, j, value) representing the source ID ("i"), the target ID ("j")
             and the distance ("value").
+
         """
         i_indices = self._stable_order(i_ids)
         j_indices = self._stable_order(j_ids)
@@ -613,15 +605,14 @@ class DissimilarityMatrix(SkbioObject):
             subset = self._data[i_idx, j_indices]
             values.append(subset)
 
-        i = pd.Series(i, name='i', dtype=str)
-        j = pd.Series(j, name='j', dtype=str)
-        values = pd.Series(np.hstack(values), name='value')
+        i = pd.Series(i, name="i", dtype=str)
+        j = pd.Series(j, name="j", dtype=str)
+        values = pd.Series(np.hstack(values), name="value")
 
         return pd.concat([i, j, values], axis=1)
 
-    @experimental(as_of="0.4.0")
     def plot(self, cmap=None, title=""):
-        """Creates a heatmap of the dissimilarity matrix
+        """Create a heatmap of the dissimilarity matrix.
 
         Parameters
         ----------
@@ -654,12 +645,13 @@ class DissimilarityMatrix(SkbioObject):
 
            Plot the dissimilarity matrix as a heatmap:
 
-           >>> fig = dm.plot(cmap='Reds', title='Example heatmap')
+           >>> fig = dm.plot(cmap='Reds', title='Example heatmap')  # doctest: +SKIP
 
         """
-        import matplotlib.pyplot as plt
+        self._get_mpl_plt()
+
         # based on http://stackoverflow.com/q/14391959/3776794
-        fig, ax = plt.subplots()
+        fig, ax = self.plt.subplots()
 
         # use pcolormesh instead of pcolor for performance
         heatmap = ax.pcolormesh(self.data, cmap=cmap)
@@ -686,41 +678,6 @@ class DissimilarityMatrix(SkbioObject):
 
         return fig
 
-    def _repr_png_(self):
-        return self._figure_data('png')
-
-    def _repr_svg_(self):
-        return self._figure_data('svg')
-
-    @property
-    @experimental(as_of="0.4.0")
-    def png(self):
-        """Display heatmap in IPython Notebook as PNG.
-
-        """
-        from IPython.core.display import Image
-        return Image(self._repr_png_(), embed=True)
-
-    @property
-    @experimental(as_of="0.4.0")
-    def svg(self):
-        """Display heatmap in IPython Notebook as SVG.
-
-        """
-        from IPython.core.display import SVG
-        return SVG(self._repr_svg_())
-
-    def _figure_data(self, format):
-        import matplotlib.pyplot as plt
-        from IPython.core.pylabtools import print_figure
-        fig = self.plot()
-        data = print_figure(fig, format)
-        # We MUST close the figure, otherwise IPython's display machinery
-        # will pick it up and send it as output, resulting in a double display
-        plt.close(fig)
-        return data
-
-    @experimental(as_of="0.4.1")
     def to_data_frame(self):
         """Create a ``pandas.DataFrame`` from this ``DissimilarityMatrix``.
 
@@ -745,7 +702,6 @@ class DissimilarityMatrix(SkbioObject):
         """
         return pd.DataFrame(data=self.data, index=self.ids, columns=self.ids)
 
-    @experimental(as_of="0.4.0")
     def __str__(self):
         """Return a string representation of the dissimilarity matrix.
 
@@ -758,11 +714,13 @@ class DissimilarityMatrix(SkbioObject):
             String representation of the dissimilarity matrix.
 
         """
-        return '%dx%d %s matrix\nIDs:\n%s\nData:\n' % (
-            self.shape[0], self.shape[1], self._matrix_element_name,
-            _pprint_strs(self.ids)) + str(self.data)
+        return "%dx%d %s matrix\nIDs:\n%s\nData:\n" % (
+            self.shape[0],
+            self.shape[1],
+            self._matrix_element_name,
+            _pprint_strs(self.ids),
+        ) + str(self.data)
 
-    @experimental(as_of="0.4.0")
     def __eq__(self, other):
         """Compare this dissimilarity matrix to another for equality.
 
@@ -803,7 +761,6 @@ class DissimilarityMatrix(SkbioObject):
 
         return equal
 
-    @experimental(as_of="0.4.0")
     def __ne__(self, other):
         """Determine whether two dissimilarity matrices are not equal.
 
@@ -824,7 +781,6 @@ class DissimilarityMatrix(SkbioObject):
         """
         return not self == other
 
-    @experimental(as_of="0.4.0")
     def __contains__(self, lookup_id):
         """Check if the specified ID is in the dissimilarity matrix.
 
@@ -846,7 +802,6 @@ class DissimilarityMatrix(SkbioObject):
         """
         return lookup_id in self._id_index
 
-    @experimental(as_of="0.4.0")
     def __getitem__(self, index):
         """Slice into dissimilarity data by object ID or numpy indexing.
 
@@ -904,8 +859,8 @@ class DissimilarityMatrix(SkbioObject):
     def _validate_ids(self, data, ids):
         """Validate the IDs.
 
-        Checks that IDs are unique and that the
-        number of IDs matches the number of rows/cols in the data array.
+        Checks that IDs are unique and that the number of IDs matches the
+        number of rows/cols in the data array.
 
         Subclasses can override this method to perform different/more specific
         validation.
@@ -920,18 +875,19 @@ class DissimilarityMatrix(SkbioObject):
         """
         duplicates = find_duplicates(ids)
         if duplicates:
-            formatted_duplicates = ', '.join(repr(e) for e in duplicates)
-            raise DissimilarityMatrixError("IDs must be unique. Found the "
-                                           "following duplicate IDs: %s" %
-                                           formatted_duplicates)
+            formatted_duplicates = ", ".join(repr(e) for e in duplicates)
+            raise DissimilarityMatrixError(
+                "IDs must be unique. Found the "
+                "following duplicate IDs: %s" % formatted_duplicates
+            )
         if 0 == len(ids):
-            raise DissimilarityMatrixError("IDs must be at least 1 in "
-                                           "size.")
+            raise DissimilarityMatrixError("IDs must be at least 1 in " "size.")
         if len(ids) != data.shape[0]:
-            raise DissimilarityMatrixError("The number of IDs (%d) must match "
-                                           "the number of rows/columns in the "
-                                           "data (%d)." %
-                                           (len(ids), data.shape[0]))
+            raise DissimilarityMatrixError(
+                "The number of IDs (%d) must match "
+                "the number of rows/columns in the "
+                "data (%d)." % (len(ids), data.shape[0])
+            )
 
     def _validate_shape(self, data):
         """Validate the data array shape.
@@ -948,18 +904,19 @@ class DissimilarityMatrix(SkbioObject):
 
         """
         if 0 in data.shape:
-            raise DissimilarityMatrixError("Data must be at least 1x1 in "
-                                           "size.")
+            raise DissimilarityMatrixError("Data must be at least 1x1 in " "size.")
         if len(data.shape) != 2:
-            raise DissimilarityMatrixError("Data must have exactly two "
-                                           "dimensions.")
+            raise DissimilarityMatrixError("Data must have exactly two " "dimensions.")
         if data.shape[0] != data.shape[1]:
-            raise DissimilarityMatrixError("Data must be square (i.e., have "
-                                           "the same number of rows and "
-                                           "columns).")
+            raise DissimilarityMatrixError(
+                "Data must be square (i.e., have "
+                "the same number of rows and "
+                "columns)."
+            )
         if data.dtype not in (np.float32, np.float64):
-            raise DissimilarityMatrixError("Data must contain only floating "
-                                           "point values.")
+            raise DissimilarityMatrixError(
+                "Data must contain only floating " "point values."
+            )
 
     def _validate(self, data, ids):
         """Validate the data array and IDs.
@@ -986,9 +943,11 @@ class DissimilarityMatrix(SkbioObject):
         return {id_: idx for idx, id_ in enumerate(list_)}
 
     def _is_id_pair(self, index):
-        return (isinstance(index, tuple) and
-                len(index) == 2 and
-                all(map(lambda e: isinstance(e, str), index)))
+        return (
+            isinstance(index, tuple)
+            and len(index) == 2
+            and all(map(lambda e: isinstance(e, str), index))
+        )
 
 
 class DistanceMatrix(DissimilarityMatrix):
@@ -1023,12 +982,10 @@ class DistanceMatrix(DissimilarityMatrix):
     """
 
     # Override here, used in superclass __str__
-    _matrix_element_name = 'distance'
+    _matrix_element_name = "distance"
 
     @classonlymethod
-    @experimental(as_of="0.4.1")
-    def from_iterable(cls, iterable, metric, key=None, keys=None,
-                      validate=True):
+    def from_iterable(cls, iterable, metric, key=None, keys=None, validate=True):
         """Create DistanceMatrix from all pairs in an iterable given a metric.
 
         Parameters
@@ -1068,13 +1025,11 @@ class DistanceMatrix(DissimilarityMatrix):
 
         """
         if validate:
-            return super(DistanceMatrix, cls).from_iterable(iterable, metric,
-                                                            key, keys)
+            return super(DistanceMatrix, cls).from_iterable(iterable, metric, key, keys)
 
         iterable = list(iterable)
         if key is not None and keys is not None:
-            raise ValueError("Cannot use both `key` and `keys` at the same"
-                             " time.")
+            raise ValueError("Cannot use both `key` and `keys` at the same" " time.")
 
         keys_ = None
         if key is not None:
@@ -1089,7 +1044,6 @@ class DistanceMatrix(DissimilarityMatrix):
 
         return cls(dm, keys_)
 
-    @experimental(as_of="0.4.0")
     def condensed_form(self):
         """Return an array of distances in condensed format.
 
@@ -1110,9 +1064,8 @@ class DistanceMatrix(DissimilarityMatrix):
         .. [1] http://docs.scipy.org/doc/scipy/reference/spatial.distance.html
 
         """
-        return squareform(self._data, force='tovector', checks=False)
+        return squareform(self._data, force="tovector", checks=False)
 
-    @experimental(as_of="0.4.0")
     def permute(self, condensed=False):
         """Randomly permute both rows and columns in the matrix.
 
@@ -1167,14 +1120,13 @@ class DistanceMatrix(DissimilarityMatrix):
         data_sym, data_hol = is_symmetric_and_hollow(data)
 
         if not data_sym:
-            raise DistanceMatrixError(
-                "Data must be symmetric and cannot contain NaNs.")
+            raise DistanceMatrixError("Data must be symmetric and cannot contain NaNs.")
 
         if not data_hol:
-            raise DistanceMatrixError("Data must be hollow (i.e., the diagonal"
-                                      " can only contain zeros).")
+            raise DistanceMatrixError(
+                "Data must be hollow (i.e., the diagonal" " can only contain zeros)."
+            )
 
-    @experimental(as_of="0.5.1")
     def to_series(self):
         """Create a ``pandas.Series`` from this ``DistanceMatrix``.
 
@@ -1225,7 +1177,6 @@ class DistanceMatrix(DissimilarityMatrix):
         return pd.Series(data=distances, index=index, dtype=float)
 
 
-@experimental(as_of="0.4.0")
 def randdm(num_objects, ids=None, constructor=None, random_fn=None):
     """Generate a distance matrix populated with random distances.
 
@@ -1273,7 +1224,7 @@ def randdm(num_objects, ids=None, constructor=None, random_fn=None):
         random_fn = np.random.rand
 
     data = np.tril(random_fn(num_objects, num_objects), -1)
-    data = data + data.T
+    data += data.T
 
     if not ids:
         ids = map(str, range(1, num_objects + 1))
@@ -1283,6 +1234,7 @@ def randdm(num_objects, ids=None, constructor=None, random_fn=None):
 
 # helper functions for anosim and permanova
 
+
 def _preprocess_input_sng(ids, sample_size, grouping, column):
     """Compute intermediate results not affected by permutations.
 
@@ -1296,18 +1248,25 @@ def _preprocess_input_sng(ids, sample_size, grouping, column):
     """
     if isinstance(grouping, pd.DataFrame):
         if column is None:
-            raise ValueError(
-                "Must provide a column name if supplying a DataFrame.")
+            raise ValueError("Must provide a column name if supplying a DataFrame.")
         else:
             grouping = _df_to_vector(ids, grouping, column)
+    elif isinstance(grouping, pd.Series):
+        if (column is not None) and (column != grouping.name):
+            raise ValueError(
+                "Column name does not match your Series name. Try not"
+                " providing column at all."
+            )
+        else:
+            grouping = _df_to_vector(ids, grouping.to_frame(), column=grouping.name)
     elif column is not None:
-        raise ValueError(
-            "Must provide a DataFrame if supplying a column name.")
+        raise ValueError("Must provide a DataFrame if supplying a column name.")
 
     if len(grouping) != sample_size:
         raise ValueError(
             "Grouping vector size must match the number of IDs in the "
-            "distance matrix.")
+            "distance matrix."
+        )
 
     # Find the group labels and convert grouping to an integer vector
     # (factor).
@@ -1319,13 +1278,15 @@ def _preprocess_input_sng(ids, sample_size, grouping, column):
             "All values in the grouping vector are unique. This method cannot "
             "operate on a grouping vector with only unique values (e.g., "
             "there are no 'within' distances because each group of objects "
-            "contains only a single object).")
+            "contains only a single object)."
+        )
     if num_groups == 1:
         raise ValueError(
             "All values in the grouping vector are the same. This method "
             "cannot operate on a grouping vector with only a single group of "
             "objects (e.g., there are no 'between' distances because there is "
-            "only a single group).")
+            "only a single group)."
+        )
 
     return num_groups, grouping
 
@@ -1345,8 +1306,9 @@ def _preprocess_input(distance_matrix, grouping, column):
         raise TypeError("Input must be a DistanceMatrix.")
     sample_size = distance_matrix.shape[0]
 
-    num_groups, grouping = _preprocess_input_sng(distance_matrix.ids,
-                                                 sample_size, grouping, column)
+    num_groups, grouping = _preprocess_input_sng(
+        distance_matrix.ids, sample_size, grouping, column
+    )
 
     tri_idxs = np.triu_indices(sample_size, k=1)
     distances = distance_matrix.condensed_form()
@@ -1386,8 +1348,8 @@ def _df_to_vector(ids, df, column):
     grouping = df.reindex(ids, axis=0).loc[:, column]
     if grouping.isnull().any():
         raise ValueError(
-            "One or more IDs in the distance matrix are not in the data "
-            "frame.")
+            "One or more IDs in the distance matrix are not in the data " "frame."
+        )
     return grouping.tolist()
 
 
@@ -1395,7 +1357,8 @@ def _run_monte_carlo_stats(test_stat_function, grouping, permutations):
     """Run stat test and compute significance with Monte Carlo permutations."""
     if permutations < 0:
         raise ValueError(
-            "Number of permutations must be greater than or equal to zero.")
+            "Number of permutations must be greater than or equal to zero."
+        )
 
     stat = test_stat_function(grouping)
 
@@ -1412,13 +1375,28 @@ def _run_monte_carlo_stats(test_stat_function, grouping, permutations):
     return stat, p_value
 
 
-def _build_results(method_name, test_stat_name, sample_size, num_groups, stat,
-                   p_value, permutations):
+def _build_results(
+    method_name, test_stat_name, sample_size, num_groups, stat, p_value, permutations
+):
     """Return ``pandas.Series`` containing results of statistical test."""
     return pd.Series(
-        data=[method_name, test_stat_name, sample_size, num_groups, stat,
-              p_value, permutations],
-        index=['method name', 'test statistic name', 'sample size',
-               'number of groups', 'test statistic', 'p-value',
-               'number of permutations'],
-        name='%s results' % method_name)
+        data=[
+            method_name,
+            test_stat_name,
+            sample_size,
+            num_groups,
+            stat,
+            p_value,
+            permutations,
+        ],
+        index=[
+            "method name",
+            "test statistic name",
+            "sample size",
+            "number of groups",
+            "test statistic",
+            "p-value",
+            "number of permutations",
+        ],
+        name="%s results" % method_name,
+    )
