@@ -7,15 +7,21 @@
 # ----------------------------------------------------------------------------
 
 import io
+import unittest
 from unittest import TestCase, main
 
-import matplotlib as mpl
 import numpy as np
 import numpy.testing as npt
 import pandas as pd
 import pandas.testing as pdt
 import scipy.spatial.distance
-from IPython.core.display import Image, SVG
+
+try:
+    import matplotlib as mpl
+except ImportError:
+    has_matplotlib = False
+else:
+    has_matplotlib = True
 
 import skbio.sequence.distance
 from skbio import DistanceMatrix, Sequence
@@ -542,6 +548,7 @@ class DissimilarityMatrixTestBase(DissimilarityMatrixTestData):
         with self.assertRaises(DissimilarityMatrixError):
             self.dm_3x3.filter([])
 
+    @unittest.skipUnless(has_matplotlib, "Matplotlib not available.")
     def test_plot_default(self):
         fig = self.dm_1x1.plot()
         self.assertIsInstance(fig, mpl.figure.Figure)
@@ -558,6 +565,7 @@ class DissimilarityMatrixTestBase(DissimilarityMatrixTestData):
             yticks.append(tick.get_text())
         self.assertEqual(yticks, ['a'])
 
+    @unittest.skipUnless(has_matplotlib, "Matplotlib not available.")
     def test_plot_no_default(self):
         ids = ['0', 'one', '2', 'three', '4.000']
         data = ([0, 1, 2, 3, 4], [1, 0, 1, 2, 3], [2, 1, 0, 1, 2],
@@ -578,25 +586,6 @@ class DissimilarityMatrixTestBase(DissimilarityMatrixTestData):
             yticks.append(tick.get_text())
         self.assertEqual(yticks, ['0', 'one', '2', 'three', '4.000'])
 
-    def test_repr_png(self):
-        dm = self.dm_1x1
-        obs = dm._repr_png_()
-        self.assertIsInstance(obs, bytes)
-        self.assertTrue(len(obs) > 0)
-
-    def test_repr_svg(self):
-        obs = self.dm_1x1._repr_svg_()
-        self.assertIsInstance(obs, str)
-        self.assertTrue(len(obs) > 0)
-
-    def test_png(self):
-        dm = self.dm_1x1
-        self.assertIsInstance(dm.png, Image)
-
-    def test_svg(self):
-        dm = self.dm_1x1
-        self.assertIsInstance(dm.svg, SVG)
-
     def test_to_data_frame_1x1(self):
         df = self.dm_1x1.to_data_frame()
         exp = pd.DataFrame([[0.0]], index=['a'], columns=['a'])
