@@ -9,15 +9,13 @@
 import functools
 
 import numpy as np
-from IPython.core.pylabtools import print_figure
-from IPython.core.display import Image, SVG
 
 from skbio._base import SkbioObject
 from skbio.stats._misc import _pprint_strs
-from skbio.util._decorator import experimental
+from skbio.util._plotting import PlottableMixin
 
 
-class OrdinationResults(SkbioObject):
+class OrdinationResults(SkbioObject, PlottableMixin):
     """Store ordination results, providing serialization and plotting support.
 
     Stores various components of ordination results. Provides methods for
@@ -56,14 +54,22 @@ class OrdinationResults(SkbioObject):
     cca
     pcoa
     rda
+
     """
-    default_write_format = 'ordination'
 
-    @experimental(as_of="0.4.0")
-    def __init__(self, short_method_name, long_method_name, eigvals,
-                 samples, features=None, biplot_scores=None,
-                 sample_constraints=None, proportion_explained=None):
+    default_write_format = "ordination"
 
+    def __init__(
+        self,
+        short_method_name,
+        long_method_name,
+        eigvals,
+        samples,
+        features=None,
+        biplot_scores=None,
+        sample_constraints=None,
+        proportion_explained=None,
+    ):
         self.short_method_name = short_method_name
         self.long_method_name = long_method_name
 
@@ -74,7 +80,6 @@ class OrdinationResults(SkbioObject):
         self.sample_constraints = sample_constraints
         self.proportion_explained = proportion_explained
 
-    @experimental(as_of="0.4.0")
     def __str__(self):
         """Return a string representation of the ordination results.
 
@@ -89,34 +94,48 @@ class OrdinationResults(SkbioObject):
             String representation of the ordination results.
 
         """
-        lines = ['Ordination results:']
-        method = '%s (%s)' % (self.long_method_name, self.short_method_name)
-        lines.append(self._format_attribute(method, 'Method', str))
+        lines = ["Ordination results:"]
+        method = "%s (%s)" % (self.long_method_name, self.short_method_name)
+        lines.append(self._format_attribute(method, "Method", str))
 
-        attrs = [(self.eigvals, 'Eigvals'),
-                 (self.proportion_explained, 'Proportion explained'),
-                 (self.features, 'Features'),
-                 (self.samples, 'Samples'),
-                 (self.biplot_scores, 'Biplot Scores'),
-                 (self.sample_constraints, 'Sample constraints')]
+        attrs = [
+            (self.eigvals, "Eigvals"),
+            (self.proportion_explained, "Proportion explained"),
+            (self.features, "Features"),
+            (self.samples, "Samples"),
+            (self.biplot_scores, "Biplot Scores"),
+            (self.sample_constraints, "Sample constraints"),
+        ]
         for attr, attr_label in attrs:
+
             def formatter(e):
-                return 'x'.join(['%d' % s for s in e.shape])
+                return "x".join(["%d" % s for s in e.shape])
 
             lines.append(self._format_attribute(attr, attr_label, formatter))
 
-        lines.append(self._format_attribute(
-            self.features, 'Feature IDs',
-            lambda e: _pprint_strs(e.index.tolist())))
-        lines.append(self._format_attribute(
-            self.samples, 'Sample IDs',
-            lambda e: _pprint_strs(e.index.tolist())))
+        lines.append(
+            self._format_attribute(
+                self.features, "Feature IDs", lambda e: _pprint_strs(e.index.tolist())
+            )
+        )
+        lines.append(
+            self._format_attribute(
+                self.samples, "Sample IDs", lambda e: _pprint_strs(e.index.tolist())
+            )
+        )
 
-        return '\n'.join(lines)
+        return "\n".join(lines)
 
-    @experimental(as_of="0.4.0")
-    def plot(self, df=None, column=None, axes=(0, 1, 2), axis_labels=None,
-             title='', cmap=None, s=20):
+    def plot(
+        self,
+        df=None,
+        column=None,
+        axes=(0, 1, 2),
+        axis_labels=None,
+        title="",
+        cmap=None,
+        s=20,
+    ):
         """Create a 3-D scatterplot of ordination results colored by metadata.
 
         Creates a 3-D scatterplot of the ordination results, where each point
@@ -181,15 +200,11 @@ class OrdinationResults(SkbioObject):
             - sample IDs in the ordination results are not in `df` or have
               missing data in `column`
 
-        See Also
-        --------
-        mpl_toolkits.mplot3d.Axes3D.scatter
-
         Notes
         -----
         This method creates basic plots of ordination results, and is intended
         to provide a quick look at the results in the context of metadata
-        (e.g., from within the IPython Notebook). For more customization and to
+        (e.g., from within the Jupyter Lab). For more customization and to
         generate publication-quality figures, we recommend EMPeror [2]_.
 
         References
@@ -230,43 +245,46 @@ class OrdinationResults(SkbioObject):
            Plot the ordination results, where each sample is colored by body
            site (a categorical variable):
 
-           >>> fig = pcoa_results.plot(df=df, column='body_site',
-           ...                         title='Samples colored by body site',
-           ...                         cmap='Set1', s=50)
+           >>> fig = pcoa_results.plot(
+           ...     df=df, column='body_site',
+           ...     title='Samples colored by body site',
+           ...     cmap='Set1', s=50
+           ... )  # doctest: +SKIP
 
         """
         # Note: New features should not be added to this method and should
         # instead be added to EMPeror (http://biocore.github.io/emperor/).
         # Only bug fixes and minor updates should be made to this method.
 
+        self._get_mpl_plt()
+
         coord_matrix = self.samples.values.T
         self._validate_plot_axes(coord_matrix, axes)
 
-        # derived from
-        # http://matplotlib.org/examples/mplot3d/scatter3d_demo.html
-        import matplotlib.pyplot as plt
-        from mpl_toolkits.mplot3d import Axes3D  # noqa
-        fig = plt.figure()
-        ax = fig.add_subplot(111, projection='3d')
+        fig = self.plt.figure()
+        ax = fig.add_subplot(projection="3d")
 
         xs = coord_matrix[axes[0]]
         ys = coord_matrix[axes[1]]
         zs = coord_matrix[axes[2]]
 
         point_colors, category_to_color = self._get_plot_point_colors(
-            df, column, self.samples.index, cmap)
+            df, column, self.samples.index, cmap
+        )
 
         scatter_fn = functools.partial(ax.scatter, xs, ys, zs, s=s)
         if point_colors is None:
             plot = scatter_fn()
         else:
-            plot = scatter_fn(c=point_colors, cmap=cmap)
+            plot = scatter_fn(c=point_colors)
 
         if axis_labels is None:
-            axis_labels = ['%d' % axis for axis in axes]
+            axis_labels = ["%d" % axis for axis in axes]
         elif len(axis_labels) != 3:
-            raise ValueError("axis_labels must contain exactly three elements "
-                             "(found %d elements)." % len(axis_labels))
+            raise ValueError(
+                "axis_labels must contain exactly three elements "
+                "(found %d elements)." % len(axis_labels)
+            )
 
         ax.set_xlabel(axis_labels[0])
         ax.set_ylabel(axis_labels[1])
@@ -282,26 +300,29 @@ class OrdinationResults(SkbioObject):
                 fig.colorbar(plot)
             else:
                 self._plot_categorical_legend(ax, category_to_color)
-        fig.tight_layout()
+
         return fig
 
     def _validate_plot_axes(self, coord_matrix, axes):
         """Validate `axes` against coordinates matrix."""
         num_dims = coord_matrix.shape[0]
         if num_dims < 3:
-            raise ValueError("At least three dimensions are required to plot "
-                             "ordination results. There are only %d "
-                             "dimension(s)." % num_dims)
+            raise ValueError(
+                "At least three dimensions are required to plot "
+                "ordination results. There are only %d "
+                "dimension(s)." % num_dims
+            )
         if len(axes) != 3:
-            raise ValueError("`axes` must contain exactly three elements "
-                             "(found %d elements)." % len(axes))
+            raise ValueError(
+                "`axes` must contain exactly three elements "
+                "(found %d elements)." % len(axes)
+            )
         if len(set(axes)) != 3:
             raise ValueError("The values provided for `axes` must be unique.")
 
         for idx, axis in enumerate(axes):
             if axis < 0 or axis >= num_dims:
-                raise ValueError("`axes[%d]` must be >= 0 and < %d." %
-                                 (idx, num_dims))
+                raise ValueError("`axes[%d]` must be >= 0 and < %d." % (idx, num_dims))
 
     def _get_plot_point_colors(self, df, column, ids, cmap):
         """Return a list of colors for each plot point given a metadata column.
@@ -310,11 +331,10 @@ class OrdinationResults(SkbioObject):
         each category (str) to color (used for legend creation).
 
         """
-        import matplotlib.pyplot as plt
-        if ((df is None and column is not None) or (df is not None and
-                                                    column is None)):
-            raise ValueError("Both df and column must be provided, or both "
-                             "must be None.")
+        if (df is None and column is not None) or (df is not None and column is None):
+            raise ValueError(
+                "Both df and column must be provided, or both " "must be None."
+            )
         elif df is None and column is None:
             point_colors, category_to_color = None, None
         else:
@@ -324,10 +344,12 @@ class OrdinationResults(SkbioObject):
             col_vals = df.reindex(ids, axis=0).loc[:, column]
 
             if col_vals.isnull().any():
-                raise ValueError("One or more IDs in the ordination results "
-                                 "are not in the data frame, or there is "
-                                 "missing data in the data frame's '%s' "
-                                 "column." % column)
+                raise ValueError(
+                    "One or more IDs in the ordination results "
+                    "are not in the data frame, or there is "
+                    "missing data in the data frame's '%s' "
+                    "column." % column
+                )
 
             category_to_color = None
             try:
@@ -338,7 +360,7 @@ class OrdinationResults(SkbioObject):
                 # colormap.
                 # derived from http://stackoverflow.com/a/14887119
                 categories = col_vals.unique()
-                cmap = plt.get_cmap(cmap)
+                cmap = self.plt.get_cmap(cmap)
                 category_colors = cmap(np.linspace(0, 1, len(categories)))
 
                 category_to_color = dict(zip(categories, category_colors))
@@ -351,59 +373,29 @@ class OrdinationResults(SkbioObject):
     def _plot_categorical_legend(self, ax, color_dict):
         """Add legend to plot using specified mapping of category to color."""
         # derived from http://stackoverflow.com/a/20505720
-        import matplotlib as mpl
         proxies = []
         labels = []
         for category in color_dict:
-            proxy = mpl.lines.Line2D([0], [0], linestyle='none',
-                                     c=color_dict[category], marker='o')
+            proxy = self.mpl.lines.Line2D(
+                [0], [0], linestyle="none", c=color_dict[category], marker="o"
+            )
             proxies.append(proxy)
             labels.append(category)
 
         # place legend outside of the axes (centered)
         # derived from http://matplotlib.org/users/legend_guide.html
-        ax.legend(proxies, labels, numpoints=1, loc=6,
-                  bbox_to_anchor=(1.05, 0.5), borderaxespad=0.)
-
-    # Here we define the special repr methods that provide the IPython display
-    # protocol. Code derived from:
-    #     https://github.com/ipython/ipython/blob/2.x/examples/Notebook/
-    #         Custom%20Display%20Logic.ipynb
-    # See licenses/ipython.txt for more details.
-
-    def _repr_png_(self):
-        return self._figure_data('png')
-
-    def _repr_svg_(self):
-        return self._figure_data('svg')
-
-    # We expose the above reprs as properties, so that the user can see them
-    # directly (since otherwise the client dictates which one it shows by
-    # default)
-    @property
-    @experimental(as_of="0.4.0")
-    def png(self):
-        """Display basic 3-D scatterplot in IPython Notebook as PNG."""
-        return Image(self._repr_png_(), embed=True)
-
-    @property
-    @experimental(as_of="0.4.0")
-    def svg(self):
-        """Display basic 3-D scatterplot in IPython Notebook as SVG."""
-        return SVG(self._repr_svg_())
-
-    def _figure_data(self, format):
-        import matplotlib.pyplot as plt
-        fig = self.plot()
-        data = print_figure(fig, format)
-        # We MUST close the figure, otherwise IPython's display machinery
-        # will pick it up and send it as output, resulting in a double display
-        plt.close(fig)
-        return data
+        ax.legend(
+            proxies,
+            labels,
+            numpoints=1,
+            loc=6,
+            bbox_to_anchor=(1.05, 0.5),
+            borderaxespad=0.0,
+        )
 
     def _format_attribute(self, attr, attr_label, formatter):
         if attr is None:
-            formatted_attr = 'N/A'
+            formatted_attr = "N/A"
         else:
             formatted_attr = formatter(attr)
-        return '\t%s: %s' % (attr_label, formatted_attr)
+        return "\t%s: %s" % (attr_label, formatted_attr)
